# python-edotenv

[![pypi package](https://badge.fury.io/py/python-edotenv.svg)](https://pypi.org/project/python-edotenv)
[![Github](https://img.shields.io/badge/Github-rrwen%2Fpython--edotenv-brightgreen?logo=Github)](https://github.com/rrwen/python-edotenv)
[![downloads](https://img.shields.io/pypi/dm/python-edotenv.svg)](https://pypistats.org/packages/python-edotenv)
[![GitHub stars](https://img.shields.io/github/stars/rrwen/python-edotenv.svg)](https://github.com/rrwen/python-edotenv/stargazers)
[![GitHub](https://img.shields.io/github/license/rrwen/python-edotenv.svg)](https://github.com/rrwen/python-edotenv/blob/main/LICENSE)
  
Save and load environmental variables using encrypted .env files.

* [Documentation](https://rrwen.github.io/python-edotenv/)
* [Developer Notes](https://github.com/rrwen/python-edotenv/blob/main/DEVELOPER.md)

## Contact

Richard Wen rrwen.dev@gmail.com
